@@ -173,7 +173,9 @@ class ISortCommand(setuptools.Command):
 
 def parse_args(argv=None):
     parser = argparse.ArgumentParser(description='Sort Python import definitions alphabetically '
-                                                 'within logical sections.')
+                                                 'within logical sections. Run with no arguments to run '
+                                                 'interactively. Run with `-` as the first argument to read from '
+                                                 'stdin. Otherwise provide a list of files to sort.')
     inline_args_group = parser.add_mutually_exclusive_group()
     parser.add_argument('-a', '--add-import', dest='add_imports', action='append',
                         help='Adds the specified import line to all files, '
@@ -294,6 +296,8 @@ def parse_args(argv=None):
                              'where it may not be safe to operate in')
     parser.add_argument('--case-sensitive', dest='case_sensitive', action='store_true',
                         help='Tells isort to include casing when sorting module names')
+    parser.add_argument('--filter-files', dest='filter_files', action='store_true',
+                        help='Tells isort to filter files even when they are explicitly passed in as part of the command')
     parser.add_argument('files', nargs='*', help='One or more Python source files that need their imports sorted.')
 
     arguments = {key: value for key, value in vars(parser.parse_args(argv)).items() if value}
@@ -343,10 +347,21 @@ def main(argv=None):
             arguments['recursive'] = True
             if not arguments.get('apply', False):
                 arguments['ask_to_apply'] = True
-        config = from_path(os.path.abspath(file_names[0]) or os.getcwd()).copy()
+
+        config = from_path(arguments.get('settings_path', '') or os.path.abspath(file_names[0]) or os.getcwd()).copy()
         config.update(arguments)
         wrong_sorted_files = False
         skipped = []
+
+        if config.get('filter_files'):
+            filtered_files = []
+            for file_name in file_names:
+                if should_skip(file_name, config):
+                    skipped.append(file_name)
+                else:
+                    filtered_files.append(file_name)
+            file_names = filtered_files
+
         if arguments.get('recursive', False):
             file_names = iter_source_code(file_names, config, skipped)
         num_skipped = 0
